Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FromFields ¶
FromFields returns a new FieldMask with given fields. It determines the paths by finding the fields with the same type in the message. So it works only when:
- The specified fields are all message types.
- The msg does not contain more than one field with the same type.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.